exceptiontools.SpacingError
===========================

.. inheritance-diagram:: abjad.tools.exceptiontools.SpacingError.SpacingError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.SpacingError.SpacingError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpacingError.SpacingError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
